@@ -6,9 +6,9 @@
 ### Methods for objects of class "twinstim", specifically:
 ### vcov, logLik, print, summary, plot, R0, residuals, update, terms, all.equal
 ###
-### Copyright (C) 2009-2017 Sebastian Meyer
-### $Revision: 1870 $
-### $Date: 2017-06-12 15:42:49 +0200 (Mon, 12. Jun 2017) $
+### Copyright (C) 2009-2018 Sebastian Meyer
+### $Revision: 2100 $
+### $Date: 2018-04-12 16:51:42 +0200 (Thu, 12. Apr 2018) $
 ################################################################################
 
 ## extract the link function used for the epidemic predictor (default: log-link)
@@ -65,7 +65,7 @@ extractAIC.twinstim <- function (fit, scale, k = 2, ...)
     c(edf = edf, AIC = -2 * c(loglik) + penalty)
 }
 
-## Number of events (excluding the pre-history)
+## Number of events (excluding the prehistory)
 nobs.twinstim <- function (object, ...) length(object$fitted)
 
 ## print-method
@@ -823,6 +823,11 @@ terms.twinstim <- function (x, component=c("endemic", "epidemic"), ...)
 ## just like all.equal.hhh4()
 all.equal.twinstim <- function (target, current, ..., ignore = NULL)
 {
+    if (!inherits(target, "twinstim"))
+        return("'target' is not a \"twinstim\" object")
+    if (!inherits(current, "twinstim"))
+        return("'current' is not a \"twinstim\" object")
+
     ignore <- unique.default(c(ignore, "runtime", "call"))
     target[ignore] <- current[ignore] <- list(NULL)
     NextMethod("all.equal")
